// Generated by ResgenSwift.Analytics 1.2

import FirebaseAnalytics

// MARK: - Protocol

protocol AnalyticsManagerProtocol {
    func logScreen(name: String, path: String)
    func logEvent(
        name: String,
        action: String,
        category: String,
        params: [String: Any]?
    )
}

// MARK: - Firebase

class FirebaseAnalyticsManager: AnalyticsManagerProtocol {
    func logScreen(name: String, path: String) {
        let parameters = [
            AnalyticsParameterScreenName: name as NSObject
        ]

        Analytics.logEvent(
            AnalyticsEventScreenView,
            parameters: parameters
        )
    }

    func logEvent(
        name: String,
        action: String,
        category: String,
        params: [String: Any]?
    ) {
        var parameters: [String:NSObject] = [
            AnalyticsParameterItemName: name.replacingOccurrences(of: " ", with: "_") as NSObject,
            AnalyticsParameterItemCategory: category as NSObject,
            "action": action as NSObject,
        ]
        
        if let supplementaryParameters = params {
            for (newKey, newValue) in supplementaryParameters {
                if parameters.contains(where: { (key: String, value: NSObject) in
                    key == newKey
                }) {
                    continue
                }
                
                parameters[newKey] = newValue as? NSObject
            }
        }
        
        Analytics.logEvent(
            AnalyticsEventSelectContent,
            parameters: parameters
        )
    }
}

// MARK: - Manager

class AnalyticsManager {
    static var shared = AnalyticsManager()
    
    // MARK: - Properties

    var managers: [AnalyticsManagerProtocol] = []

    private var isEnabled: Bool = true

    // MARK: - Methods

    func setAnalyticsEnabled(_ enable: Bool) {
        isEnabled = enable
    }

    func configure() {
        managers.append(FirebaseAnalyticsManager())
    }
        
    private func logScreen(name: String, path: String) {
        guard isEnabled else { return }

        managers.forEach { manager in
            manager.logScreen(name: name, path: path)
        }
    }
    
    private func logEvent(
        name: String,
        action: String,
        category: String,
        params: [String: Any]?
    ) {
        guard isEnabled else { return }

        managers.forEach { manager in
            manager.logEvent(
                name: name,
                action: action,
                category: category,
                params: params
            )
        }
    }

    // MARK: - section_one

    func logScreenS1DefOne(title: String) {
        logScreen(
            name: "s1 def one \(title)",
            path: ""
        )
    }

    func logEventS1DefTwo(title: String, count: String) {
        logEvent(
            name: "s1 def two",
            action: "test",
            category: "test",
            params: [
                "title": title,
				"count": count
            ]
        )
    }

    // MARK: - section_two

    func logScreenS2DefOne() {
        logScreen(
            name: "s2 def one",
            path: ""
        )
    }
}
